==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/RejectTransitGatewayMulticastDomainAssociationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RejectTransitGatewayMulticastDomainAssociationsResponse(
    associations: Optional[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse = {
    import RejectTransitGatewayMulticastDomainAssociationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
      .builder()
      .optionallyWith(associations.map(value => value.buildAwsValue()))(
        _.associations
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse.ReadOnly =
    zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
      .wrap(buildAwsValue())
}
object RejectTransitGatewayMulticastDomainAssociationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse =
      zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse(
        associations.map(value => value.asEditable)
      )
    def associations: Optional[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ]
    def getAssociations: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ] = AwsError.unwrapOptionField("associations", associations)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
  ) extends zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse.ReadOnly {
    override val associations: Optional[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.associations())
      .map(value =>
        zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
  ): zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.104.13-sources.jar: zio/aws/ec2/model/RejectTransitGatewayMulticastDomainAssociationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RejectTransitGatewayMulticastDomainAssociationsResponse(
    associations: Option[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse = {
    import RejectTransitGatewayMulticastDomainAssociationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
      .builder()
      .optionallyWith(associations.map(value => value.buildAwsValue()))(
        _.associations
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse.ReadOnly =
    zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
      .wrap(buildAwsValue())
}
object RejectTransitGatewayMulticastDomainAssociationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse =
      zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse(
        associations.map(value => value.asEditable)
      )
    def associations: Option[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ]
    def getAssociations: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ] = AwsError.unwrapOptionField("associations", associations)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
  ) extends zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse.ReadOnly {
    override val associations: Option[
      zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.ReadOnly
    ] = scala
      .Option(impl.associations())
      .map(value =>
        zio.aws.ec2.model.TransitGatewayMulticastDomainAssociations.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse
  ): zio.aws.ec2.model.RejectTransitGatewayMulticastDomainAssociationsResponse.ReadOnly =
    new Wrapper(impl)
}
